@@ -52,10 +52,14 @@ def main(args=None):  # pylint: disable=R0915
                         help="do not validate external file references")
     parser.add_argument('-C', '--no-child-check', action='store_true',
                         help="do not validate child (reverse) links")
+    parser.add_argument('-Z', '--strict-child-check', action='store_true',
+                        help="require child (reverse) links from every document")
     parser.add_argument('-S', '--no-suspect-check', action='store_true',
                         help="do not check for suspect links")
     parser.add_argument('-W', '--no-review-check', action='store_true',
                         help="do not check item review status")
+    parser.add_argument('-s', '--skip', metavar='PREFIX', action='append',
+                        help="skip a document during validation")
     parser.add_argument('-w', '--warn-all', action='store_true',
                         help="display all info-level issues as warnings")
     parser.add_argument('-e', '--error-all', action='store_true',
@@ -90,6 +94,9 @@ def main(args=None):  # pylint: disable=R0915
     function = commands.get(args.command)
     try:
         success = function(args, os.getcwd(), parser.error)
+    except common.DoorstopFileError as exc:
+        log.error(exc)
+        success = False
     except KeyboardInterrupt:
         log.debug("command cancelled")
         success = False
@@ -289,7 +296,10 @@ def _publish(subs, shared):
     sub.add_argument('-C', '--no-child-links', action='store_true',
                      help="do not include child links on items")
     sub.add_argument('-L', '--no-body-levels', action='store_true',
+                     default=None,
                      help="do not include levels on non-heading items")
+    sub.add_argument('--no-levels', choices=['all', 'body'],
+                     help="do not include levels on heading and non-heading or non-heading items")
 
 
 if __name__ == '__main__':  # pragma: no cover (manual test)
