@@ -7,7 +7,7 @@ from doorstop.cli.main import main
 from doorstop import settings
 
 ROOT = os.path.join(os.path.dirname(__file__), '..', '..', '..')
-REQS = os.path.join(ROOT, 'docs', 'reqs')
+REQS = os.path.join(ROOT, 'reqs')
 TUTORIAL = os.path.join(REQS, 'tutorial')
 FILES = os.path.join(os.path.dirname(__file__), 'files')
 
@@ -16,7 +16,6 @@ REASON = "'{0}' variable not set".format(ENV)
 
 
 class SettingsTestCase(unittest.TestCase):
-
     """Base test case class that backs up settings."""
 
     def setUp(self):
