@@ -9,12 +9,13 @@ import tempfile
 import shutil
 import pprint
 import logging
+import warnings
 
 import yaml
 import openpyxl
 
 from doorstop import common
-from doorstop.common import DoorstopWarning, DoorstopError
+from doorstop.common import DoorstopError, DoorstopWarning, DoorstopInfo
 from doorstop import core
 from doorstop.core.builder import _get_tree, _clear_tree
 from doorstop.core.vcs import mockvcs
@@ -37,9 +38,7 @@ CHECK_EXPORTED_CONTENT = True
 CHECK_PUBLISHED_CONTENT = True
 
 
-@unittest.skipUnless(os.getenv(ENV), REASON)
 class TestItem(unittest.TestCase):
-
     """Integration tests for the Item class."""
 
     def setUp(self):
@@ -62,6 +61,7 @@ class TestItem(unittest.TestCase):
         self.assertEqual("Hello, world!", item2.text)
         self.assertEqual(['SYS001', 'SYS002'], item2.links)
 
+    @unittest.skipUnless(os.getenv(ENV), REASON)
     def test_find_ref(self):
         """Verify an item's external reference can be found."""
         item = core.Item(os.path.join(FILES, 'REQ003.yml'))
@@ -79,9 +79,7 @@ class TestItem(unittest.TestCase):
         self.assertRaises(DoorstopError, self.item.find_ref)
 
 
-@unittest.skipUnless(os.getenv(ENV), REASON)
 class TestDocument(unittest.TestCase):
-
     """Integration tests for the Document class."""
 
     def setUp(self):
@@ -110,11 +108,13 @@ class TestDocument(unittest.TestCase):
         self.assertEqual(0, len(document.items))
 
     @patch('doorstop.settings.REORDER', False)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     def test_validate(self):
         """Verify a document can be validated."""
         self.assertTrue(self.document.validate())
 
     @patch('doorstop.settings.REORDER', False)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     def test_issues_count(self):
         """Verify a number of issues are found in a document."""
         issues = self.document.issues
@@ -123,6 +123,7 @@ class TestDocument(unittest.TestCase):
         self.assertEqual(12, len(issues))
 
     @patch('doorstop.settings.REORDER', False)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     def test_issues_duplicate_level(self):
         """Verify duplicate item levels are detected."""
         expect = DoorstopWarning("duplicate level: 2.1 (REQ002, REQ2-001)")
@@ -134,9 +135,10 @@ class TestDocument(unittest.TestCase):
             self.fail("issue not found: {}".format(expect))
 
     @patch('doorstop.settings.REORDER', False)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     def test_issues_skipped_level(self):
         """Verify skipped item levels are detected."""
-        expect = DoorstopWarning("skipped level: 1.4 (REQ003), 1.6 (REQ004)")
+        expect = DoorstopInfo("skipped level: 1.4 (REQ003), 1.6 (REQ004)")
         for issue in self.document.issues:
             logging.info(repr(issue))
             if type(issue) == type(expect) and issue.args == expect.args:
@@ -194,7 +196,7 @@ class TestDocument(unittest.TestCase):
         document.add_item(level='1.0', reorder=False)
         document.reorder(keep=item)
         expected = [(1, 0), (2, 0), (3, 0)]
-        actual = [item.level for item in document.items]
+        actual = [i.level for i in document.items]
         self.assertListEqual(expected, actual)
         self.assertEqual((1, 0), item.level)
 
@@ -215,6 +217,7 @@ class TestDocument(unittest.TestCase):
         self.assertListEqual(expected, actual)
 
     @patch('doorstop.settings.REORDER', True)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     def test_validate_with_reordering(self):
         """Verify a document's order is corrected during validation."""
         document = core.Document.new(None,
@@ -232,9 +235,7 @@ class TestDocument(unittest.TestCase):
         self.assertListEqual(expected, actual)
 
 
-@unittest.skipUnless(os.getenv(ENV), REASON)
 class TestTree(unittest.TestCase):
-
     """Integration tests for the core.Tree class."""
 
     def setUp(self):
@@ -248,6 +249,30 @@ class TestTree(unittest.TestCase):
         common.write_text(self.backup, self.path)
 
     @patch('doorstop.settings.REORDER', False)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
+    @patch('doorstop.settings.STAMP_NEW_LINKS', False)
+    @patch('doorstop.settings.CHECK_REF', False)
+    def test_issues_count(self):
+        """Verify a number of issues are found in a tree."""
+        issues = self.tree.issues
+        for issue in self.tree.issues:
+            logging.info(repr(issue))
+        self.assertEqual(14, len(issues))
+
+    @patch('doorstop.settings.REORDER', False)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
+    @patch('doorstop.settings.STAMP_NEW_LINKS', False)
+    @patch('doorstop.settings.CHECK_REF', False)
+    def test_issues_count_with_skips(self):
+        """Verify a document can be skipped during validation."""
+        issues = list(self.tree.get_issues(skip=['req']))
+        for issue in self.tree.issues:
+            logging.info(repr(issue))
+        self.assertEqual(2, len(issues))
+
+    @patch('doorstop.settings.REORDER', False)
+    @patch('doorstop.settings.STAMP_NEW_LINKS', False)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     @patch('doorstop.core.document.Document', DocumentNoSkip)
     def test_validate_invalid_link(self):
         """Verify a tree is invalid with a bad link."""
@@ -257,6 +282,7 @@ class TestTree(unittest.TestCase):
         self.assertFalse(tree.validate())
 
     @patch('doorstop.settings.REORDER', False)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     def test_validate_long(self):
         """Verify trees can be checked."""
         logging.info("tree: {}".format(self.tree))
@@ -265,13 +291,10 @@ class TestTree(unittest.TestCase):
 
 @unittest.skipUnless(os.getenv(ENV), REASON)
 class TestEditor(unittest.TestCase):
-
     """Integrations tests for the editor module."""
 
 
-@unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0902
 class TestImporter(unittest.TestCase):
-
     """Integrations tests for the importer module."""
 
     def setUp(self):
@@ -341,6 +364,7 @@ class TestImporter(unittest.TestCase):
         log_data(expected, actual)
         self.assertListEqual(expected, actual)
 
+    @unittest.skipUnless(os.getenv(ENV), REASON)
     def test_import_xlsx(self):
         """Verify items can be imported from an XLSX file."""
         path = os.path.join(self.temp, 'exported.xlsx')
@@ -356,6 +380,28 @@ class TestImporter(unittest.TestCase):
         log_data(expected, actual)
         self.assertListEqual(expected, actual)
 
+    # TODO: determine when this test should be run (if at all)
+    # currently, 'TEST_LONG' isn't set under any condition
+    @unittest.skipUnless(os.getenv(ENV), REASON)
+    @unittest.skipUnless(os.getenv('TEST_LONG'), "this test takes too long")
+    @unittest.skipIf(os.getenv('TRAVIS'), "this test takes too long")
+    def test_import_xlsx_huge(self):
+        """Verify huge XLSX files are handled."""
+        path = os.path.join(FILES, 'exported-huge.xlsx')
+        _path = os.path.join(self.temp, 'imports', 'req')
+        _tree = _get_tree()
+        document = _tree.create_document(_path, 'REQ')
+        # Act
+        with warnings.catch_warnings(record=True) as warns:
+            core.importer.import_file(path, document)
+            # Assert
+        self.assertEqual(1, len(warns))
+        self.assertIn("maximum number of rows", str(warns[-1].message))
+        expected = []
+        actual = [item.data for item in document.items]
+        log_data(expected, actual)
+        self.assertListEqual(expected, actual)
+
     def test_create_document(self):
         """Verify a new document can be created to import items."""
         document = core.importer.create_document(self.prefix, self.path)
@@ -416,9 +462,7 @@ class TestImporter(unittest.TestCase):
         self.assertEqual(attrs['ext1'], item.get('ext1'))
 
 
-@unittest.skipUnless(os.getenv(ENV) or not CHECK_EXPORTED_CONTENT, REASON)
 class TestExporter(unittest.TestCase):
-
     """Integration tests for the doorstop.core.exporter module."""
 
     maxDiff = None
@@ -458,6 +502,7 @@ class TestExporter(unittest.TestCase):
             self.assertEqual(expected, actual)
         move_file(temp, path)
 
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     def test_export_tsv(self):
         """Verify a document can be exported as a TSV file."""
         path = os.path.join(FILES, 'exported.tsv')
@@ -472,6 +517,7 @@ class TestExporter(unittest.TestCase):
             self.assertEqual(expected, actual)
         move_file(temp, path)
 
+    @unittest.skipUnless(os.getenv(ENV) or not CHECK_EXPORTED_CONTENT, REASON)
     def test_export_xlsx(self):
         """Verify a document can be exported as an XLSX file."""
         path = os.path.join(FILES, 'exported.xlsx')
@@ -488,9 +534,7 @@ class TestExporter(unittest.TestCase):
             move_file(temp, path)
 
 
-@unittest.skipUnless(os.getenv(ENV) or not CHECK_PUBLISHED_CONTENT, REASON)
 class TestPublisher(unittest.TestCase):
-
     """Integration tests for the doorstop.core.publisher module."""
 
     maxDiff = None
@@ -616,9 +660,7 @@ class TestPublisher(unittest.TestCase):
         common.write_text(text, path)
 
 
-@unittest.skipUnless(os.getenv(ENV), REASON)
 class TestModule(unittest.TestCase):
-
     """Integration tests for the doorstop.core module."""
 
     def setUp(self):
