@@ -15,17 +15,17 @@ from doorstop.core.builder import _set_tree
 
 from doorstop.core.test.test_document import FILES, MockItem
 
-LOREM_IPSUM = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed \
-do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad \
-minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex \
-ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate \
-velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat \
-cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id \
-est laborum."
+LOREM_IPSUM = '''Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod
+tempor incididunt ut labore et dolore magna aliqua.
+Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut
+aliquip ex ea commodo consequat.
+Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore
+eu fugiat nulla pariatur.
+Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia
+deserunt mollit anim id est laborum.'''
 
 
 class TestModule(unittest.TestCase):
-
     """Unit tests for the doorstop.core.importer module."""  # pylint: disable=R0201
 
     maxDiff = None
@@ -145,7 +145,7 @@ class TestModule(unittest.TestCase):
 
     @patch('doorstop.core.importer._itemize')
     def test_file_xlsx(self, mock_itemize):
-        """Verify a CSV file can be imported."""  # pylint: disable=C0301
+        """Verify a XLSX file can be imported."""  # pylint: disable=C0301
         path = os.path.join(FILES, 'exported.xlsx')
         mock_document = Mock()
         # Act
@@ -299,7 +299,6 @@ class TestModule(unittest.TestCase):
 
 
 class TestModuleCreateDocument(unittest.TestCase):
-
     """Unit tests for the doorstop.core.importer:create_document function."""
 
     def setUp(self):
@@ -359,7 +358,6 @@ class TestModuleCreateDocument(unittest.TestCase):
 
 @patch('doorstop.core.item.Item', MockItem)
 class TestModuleAddItem(unittest.TestCase):
-
     """Unit tests for the doorstop.core.importer:add_item function."""
 
     prefix = 'PREFIX'
