@@ -28,7 +28,6 @@ text: ''
 
 
 class TestItem(unittest.TestCase):
-
     """Unit tests for the Item class."""  # pylint: disable=W0212
 
     def setUp(self):
@@ -235,15 +234,11 @@ class TestItem(unittest.TestCase):
         """Verify newlines separate sentences in an item's text."""
         value = ("A sentence. Another sentence! Hello? Hi.\n"
                  "A new line (here). And another sentence.")
-        text = ("A sentence. Another sentence! Hello? Hi. "
+        text = ("A sentence. Another sentence! Hello? Hi.\n"
                 "A new line (here). And another sentence.")
         yaml = ("text: |\n"
-                "  A sentence.\n"
-                "  Another sentence!\n"
-                "  Hello?\n"
-                "  Hi.\n"
-                "  A new line (here).\n"
-                "  And another sentence.\n")
+                "  A sentence. Another sentence! Hello? Hi.\n"
+                "  A new line (here). And another sentence.\n")
         self.item.text = value
         self.assertEqual(text, self.item.text)
         self.assertIn(yaml, self.item._write.call_args[0][0])
@@ -261,9 +256,9 @@ class TestItem(unittest.TestCase):
         self.assertEqual(expected, self.item.text)
 
     def test_text_split_numbers(self):
-        """Verify lines ending in numbers are joined correctly."""
+        """Verify lines ending in numbers aren't changed."""
         self.item.text = "Split at a number: 1\n42 or punctuation.\nHere."
-        expected = "Split at a number: 1 42 or punctuation. Here."
+        expected = "Split at a number: 1\n42 or punctuation.\nHere."
         self.assertEqual(expected, self.item.text)
 
     def test_text_newlines(self):
@@ -273,15 +268,15 @@ class TestItem(unittest.TestCase):
         self.assertEqual(expected, self.item.text)
 
     def test_text_formatting(self):
-        """Verify newlines are removed around formatting."""
+        """Verify newlines are not removed around formatting."""
         self.item.text = "The thing\n**_SHALL_** do this.\n"
-        expected = "The thing **_SHALL_** do this."
+        expected = "The thing\n**_SHALL_** do this."
         self.assertEqual(expected, self.item.text)
 
     def test_text_non_heading(self):
-        """Verify newlines are removed around non-headings."""
+        """Verify newlines are preserved around non-headings."""
         self.item.text = "break (before \n#2) symbol should not be a heading."
-        expected = "break (before #2) symbol should not be a heading."
+        expected = "break (before\n#2) symbol should not be a heading."
         self.assertEqual(expected, self.item.text)
 
     def test_text_heading(self):
@@ -601,6 +596,19 @@ class TestItem(unittest.TestCase):
         stamp = 'c6a87755b8756b61731c704c6a7be4a2'
         self.assertEqual(stamp, self.item._data['reviewed'])
 
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
+    def test_validate_reviewed_first(self):
+        """Verify that a missing initial review leaves the stamp empty."""
+        self.item._data['reviewed'] = Stamp(None)
+        self.assertTrue(self.item.validate())
+        self.assertEqual(Stamp(None), self.item._data['reviewed'])
+
+    @patch('doorstop.settings.ERROR_ALL', True)
+    def test_validate_reviewed_second(self):
+        """Verify that a modified stamp fails review."""
+        self.item._data['reviewed'] = Stamp('abc123')
+        self.assertFalse(self.item.validate())
+
     def test_validate_cleared(self):
         """Verify that checking a cleared link updates the stamp."""
         mock_item = Mock()
@@ -612,12 +620,24 @@ class TestItem(unittest.TestCase):
         self.assertTrue(self.item.validate())
         self.assertEqual('abc123', self.item.links[0].stamp)
 
+    def test_validate_cleared_new(self):
+        """Verify that new links are stamped automatically."""
+        mock_item = Mock()
+        mock_item.stamp = Mock(return_value=Stamp('abc123'))
+        mock_tree = MagicMock()
+        mock_tree.find_item = Mock(return_value=mock_item)
+        self.item.tree = mock_tree
+        self.item.links = [{'mock_uid': None}]
+        self.assertTrue(self.item.validate())
+        self.assertEqual('abc123', self.item.links[0].stamp)
+
     def test_validate_nonnormative_with_links(self):
         """Verify a non-normative item with links can be checked."""
         self.item.normative = False
         self.item.links = ['a']
         self.assertTrue(self.item.validate())
 
+    @patch('doorstop.settings.STAMP_NEW_LINKS', False)
     def test_validate_link_to_inactive(self):
         """Verify a link to an inactive item can be checked."""
         mock_item = Mock()
@@ -628,6 +648,7 @@ class TestItem(unittest.TestCase):
         self.item.tree = mock_tree
         self.assertTrue(self.item.validate())
 
+    @patch('doorstop.settings.STAMP_NEW_LINKS', False)
     def test_validate_link_to_nonnormative(self):
         """Verify a link to an non-normative item can be checked."""
         mock_item = Mock()
@@ -661,6 +682,7 @@ class TestItem(unittest.TestCase):
         self.item.document = mock_document
         self.assertFalse(self.item.validate())
 
+    @patch('doorstop.settings.STAMP_NEW_LINKS', False)
     def test_validate_tree(self):
         """Verify an item can be checked against a tree."""
 
@@ -697,6 +719,7 @@ class TestItem(unittest.TestCase):
         self.item.tree = mock_tree
         self.assertFalse(self.item.validate())
 
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     def test_validate_both(self):
         """Verify an item can be checked against both."""
 
@@ -724,6 +747,8 @@ class TestItem(unittest.TestCase):
 
         self.assertTrue(self.item.validate())
 
+    @patch('doorstop.settings.STAMP_NEW_LINKS', False)
+    @patch('doorstop.settings.REVIEW_NEW_ITEMS', False)
     def test_validate_both_no_reverse_links(self):
         """Verify an item can be checked against both (no reverse links)."""
 
@@ -813,7 +838,6 @@ class TestItem(unittest.TestCase):
 
 
 class TestFormatting(unittest.TestCase):
-
     """Unit tests for text formatting in Items."""
 
     ITEM = os.path.join(FILES, 'REQ001.yml')
@@ -835,7 +859,6 @@ class TestFormatting(unittest.TestCase):
 
 
 class TestUnknownItem(unittest.TestCase):
-
     """Unit tests for the UnknownItem class."""  # pylint: disable= W0212
 
     def setUp(self):
