@@ -8,11 +8,10 @@ import os
 from doorstop.common import DoorstopError
 from doorstop.core import publisher
 
-from doorstop.core.test import FILES, EMPTY, MockDataMixIn
+from doorstop.core.test import FILES, EMPTY, MockDataMixIn, MockItemAndVCS
 
 
 class TestModule(MockDataMixIn, unittest.TestCase):
-
     """Unit tests for the doorstop.core.publisher module."""
 
     @patch('os.makedirs')
@@ -90,7 +89,7 @@ class TestModule(MockDataMixIn, unittest.TestCase):
         path2 = publisher.publish(mock_tree, dirpath, index=False)
         # Assert
         self.assertIs(None, path2)
-        mock_index.assert_never_called()
+        self.assertEqual(0, mock_index.call_count)
 
     def test_index(self):
         """Verify an HTML index can be created."""
@@ -153,13 +152,45 @@ class TestModule(MockDataMixIn, unittest.TestCase):
         # Assert
         self.assertEqual(expected, text)
 
+    @patch('doorstop.settings.PUBLISH_HEADING_LEVELS', False)
+    def test_lines_text_item_heading_no_heading_levels(self):
+        """Verify an item heading level can be ommitted."""
+        expected = "Heading\n\n"
+        lines = publisher.publish_lines(self.item, '.txt')
+        # Act
+        text = ''.join(line + '\n' for line in lines)
+        # Assert
+        self.assertEqual(expected, text)
+
+    def test_single_line_heading_to_markdown(self):
+        """A single line heading is published as a heading with an attribute equal to the item id"""
+        expected = "## 1.1 Heading {#req3 }\n\n"
+        lines = publisher.publish_lines(self.item, '.md', linkify=True)
+        # Act
+        text = ''.join(line + '\n' for line in lines)
+        # Assert
+        self.assertEqual(expected, text)
+
+    def test_multi_line_heading_to_markdown(self):
+        """A multi line heading is published as a heading with an attribute equal to the item id"""
+        item = MockItemAndVCS('path/to/req3.yml',
+                              _file=("links: [sys3]" + '\n'
+                                     "text: 'Heading\n\nThis section describes publishing.'" + '\n'
+                                     "level: 1.1.0" + '\n'
+                                     "normative: false"))
+        expected = "## 1.1 Heading {#req3 }\nThis section describes publishing.\n\n"
+        lines = publisher.publish_lines(item, '.md', linkify=True)
+        # Act
+        text = ''.join(line + '\n' for line in lines)
+        # Assert
+        self.assertEqual(expected, text)
+
     @patch('doorstop.settings.PUBLISH_CHILD_LINKS', False)
     def test_lines_text_item_normative(self):
         """Verify text can be published from an item (normative)."""
         expected = ("1.2     req4" + '\n\n'
                     "        This shall..." + '\n\n'
-                    "        Reference: Doorstop.sublime-project"
-                    + '\n\n'
+                    "        Reference: Doorstop.sublime-project" + '\n\n'
                     "        Links: sys4" + '\n\n')
         lines = publisher.publish_lines(self.item3, '.txt')
         # Act
@@ -193,7 +224,17 @@ class TestModule(MockDataMixIn, unittest.TestCase):
 
     def test_lines_markdown_item_heading(self):
         """Verify Markdown can be published from an item (heading)."""
-        expected = "## 1.1 Heading {: #req3 }\n\n"
+        expected = "## 1.1 Heading {#req3 }\n\n"
+        # Act
+        lines = publisher.publish_lines(self.item, '.md', linkify=True)
+        text = ''.join(line + '\n' for line in lines)
+        # Assert
+        self.assertEqual(expected, text)
+
+    @patch('doorstop.settings.PUBLISH_HEADING_LEVELS', False)
+    def test_lines_markdown_item_heading_no_heading_levels(self):
+        """Verify an item heading level can be ommitted."""
+        expected = "## Heading {#req3 }\n\n"
         # Act
         lines = publisher.publish_lines(self.item, '.md', linkify=True)
         text = ''.join(line + '\n' for line in lines)
@@ -261,6 +302,16 @@ class TestModule(MockDataMixIn, unittest.TestCase):
         # Assert
         self.assertEqual(expected, text)
 
+    @patch('doorstop.settings.PUBLISH_HEADING_LEVELS', False)
+    def test_lines_html_item_no_heading_levels(self):
+        """Verify an item heading level can be ommitted."""
+        expected = '<h2>Heading</h2>\n'
+        # Act
+        lines = publisher.publish_lines(self.item, '.html')
+        text = ''.join(line + '\n' for line in lines)
+        # Assert
+        self.assertEqual(expected, text)
+
     def test_lines_html_item_linkify(self):
         """Verify HTML (hyper) can be published from an item."""
         expected = '<h2 id="req3">1.1 Heading</h2>\n'
