@@ -1,4 +1,4 @@
-"""Package for the doorstop.web tests."""
+"""Package for the doorstop.server tests."""
 
 ENV = 'TEST_INTEGRATION'  # environment variable to enable integration tests
 REASON = "'{0}' variable not set".format(ENV)
